@@ -5,6 +5,7 @@ from snakes.lang import unparse
 import snakes.utils.abcd.transform as transform
 from snakes.data import MultiSet
 from snakes import *
+from snakes.compat import *
 
 class Decl (object) :
     OBJECT = "object"
@@ -90,8 +91,11 @@ class Builder (object) :
         """raise an exception with appropriate location
         """
         if self.stack :
-            pos = "[%s:%s]: " % (self.stack[-1].lineno,
-                                 self.stack[-1].col_offset)
+            try :
+                pos = "[%s:%s]: " % (self.stack[-1].lineno,
+                                     self.stack[-1].col_offset)
+            except :
+                pos = ""
         else :
             pos = ""
         raise error(pos+message)
@@ -432,7 +436,24 @@ class Builder (object) :
         self.instances.add(name)
         path = self.path + [name]
         builder = self.__class__(self.snk, path, self)
-        return builder.build(spec)
+        net = builder.build(spec)
+        src = (node.st.source(),
+               node.st.srow, node.st.scol,
+               node.st.erow, node.st.ecol)
+        for trans in net.transition() :
+            try :
+                lbl = trans.label("instances")
+                trans.label(instances=[src] + lbl)
+            except KeyError :
+                trans.label(instances=[src])
+        for place in net.place() :
+            if place.status == self.snk.Status(None) :
+                try :
+                    lbl = place.label("instances")
+                    place.label(instances=[src] + lbl)
+                except KeyError :
+                    place.label(instances=[src])
+        return net
     # control flow operations
     def build_Sequence (self, node) :
         return self.snk.PetriNet.__and__
